/*
	Description: Creates Appendix Table 3 (summary statistics for direct and indirect trade shocks)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all
capture restore, not

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Summary stats
foreach v in "d_import_usch_1991_2011" "d_import_otch_1991_2011" "d_up_usch_1991_2011" "d_up_otch_1991_2011" "d_down_usch_1991_2011" "d_down_otch_1991_2011" "d_up_LT_usch_1991_2011" "d_up_LT_otch_1991_2011" "d_down_LT_usch_1991_2011" "d_down_LT_otch_1991_2011" {
	forvalues m = 0/1 {
		* Compute summary statistics, weighting by industry size at start of period
		quietly sum `v' if manuf == `m' [aw = cbp_emp1991], detail

		local n_`m' = r(N)
		local mean_`m' = r(mean)
		local sd_`m' = r(sd)
		local median_`m' = r(p50)
		local min_`m' = r(min)
		local max_`m' = r(max)
	}

	* Row of means, medians, mins, maxes
	mat row1 = (`n_1', `mean_1', `median_1', `min_1', `max_1', `n_0', `mean_0', `median_0', `min_0', `max_0')
	mat rownames row1 = "`v'"

	* Row of standard deviations
	mat row2 = (., `sd_1', ., ., ., ., `sd_0', ., ., .)
	mat rownames row2 = "`v'"

	* Tack on to stats matrix
	capture confirm mat stats
	if _rc != 0 {
		mat stats = row1
	}
	else {
		mat stats = (stats \ row1)
	}
	mat stats = (stats \ row2)
}

* Load a dataset of summary stats into memory
clear
svmat stats

* Add a column indicating variable names
local names: rownames stats
mat drop stats

gen v = ""
order v

forvalues i = 1/`=_N' {
	local name: word `i' of `names'
	replace v = "`name'" in `i'
}

* Update the "raw data" sheet in the Excel file
export excel "`outdir'/AADHP-JOLE-Appendix.xlsx", sheetreplace sheet(AppTab3_Raw)


