/*
	Description: Creates Table 4 (falsification exercise)

	Author: Brendan Price
	Updated: August 4, 2014
*/

version 12.1
set more off
clear all

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Restrict attention to manufacturing industries that are not reclassified to non-manufacturing under NAICS
keep if manuf == 1 & reclassified == 0

* Specify controls
local sector_controls "sector2 sector3 sector4 sector5 sector6 sector7 sector8 sector9 sector10"

keep sic87dd sic3 nber_emp* d_import_usch_1991_2011 d_import_otch_1991_2011 `sector_controls'

* Compute annualized log employment changes
foreach t in "1971_1981" "1981_1991" "1991_1999" "1999_2009" "1991_2009" {
	local start = substr("`t'", 1, 4)
	local end = substr("`t'", 6, 4)

	* Create annualized log employment changes
	gen dl_nber_emp_`t' = 100 * (log(nber_emp`end') - log(nber_emp`start')) / (`end' - `start')
}

foreach c in "noctrl" "ctrl" {
	if "`c'" == "noctrl" {
		local sectors ""
	}
	else if "`c'" == "ctrl" {
		local sectors "`sector_controls'"
	}

	estimates clear

	foreach t in "1971_1981" "1981_1991" "1991_1999" "1999_2009" "1991_2009" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		* Specify dependent variable
		local yvar "dl_nber_emp_`t'"

		* Weighting and clustering: always cluster by 3-digit industry
		local aw = "[aw = nber_emp1991]"
		local vce = "vce(cluster sic3)"

		eststo: quietly ivregress 2sls `yvar' `sectors' (d_import_usch_1991_2011 = d_import_otch_1991_2011) `aw', `vce'	
	}

	tempfile specs

	#delimit ;
	esttab * using "`specs'.csv",
		nodepvars
		collabels(, none)
		mlabels("1971-1981" "1981-1991" "1991-1999" "1999-2009" "1991-2009")
		b(%9.2f) se(%9.2f)
		order(d_import_usch_1991_2011 _cons)
		keep(d_import_usch_1991_2011 _cons)
		star(* .10 ** .05 *** .01)
		nonotes
		label
		stats(N, labels("N") fmt(0 0))
		replace;
	#delimit cr

	* Switch the output to Excel format
	preserve
	insheet using "`specs'.csv", comma clear
	if "`c'" == "noctrl" {
		export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetreplace sheet(Tab4_Raw)
	}
	else if "`c'" == "ctrl" {
		export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetmodify sheet(Tab4_Raw) cell(A10)
	}
	restore
}

